@@ -146,7 +146,7 @@ def clustering_model(pca_df,num_PCA_components,original_df):
 
     print(pca_df_final)
 
-    return pca_df_final
+    return pca_df_final,user_clusters
 
 
 # def clustering_model(pca_df):
