@@ -47,8 +47,7 @@ for attempt in range(10):  # user has ten times to get a correct path, otherwise
         # user_input_directory = "/Users/matthewnwerem/Chapman University/OMO Research Group - Project Conf. Analysis - Nwerem - proj_conf_analysis/Code Versions/Conformational_Analysis/xyz_file_test"
         # user_input_directory = "/Users/matthewnwerem/Chapman University/OMO Research Group - Project Conf. Analysis - Nwerem - proj_conf_analysis/Code Versions/Conformational_Analysis/1_4_dioxepane_file_test"
         # user_input_directory = "/Users/matthewnwerem/Chapman University/OMO Research Group - Project Conf. Analysis - Nwerem - proj_conf_analysis/Code Versions/Conformational_Analysis/1fluoro4propylcyclohexane"
-        # user_input_directory = "/Users/matthewnwerem/Chapman University/OMO Research Group - Project Conf. Analysis - Nwerem - proj_conf_analysis/Code Versions/Conformational_Analysis/cis_1fluoro4propylcyclohexane"
-
+        user_input_directory = "/Users/matthewnwerem/Chapman University/OMO Research Group - Project Conf. Analysis - Nwerem - proj_conf_analysis/Code Versions/Conformational_Analysis/test_files/cis_1fluoro4propylcyclohexane"
 
         # 1,4,7,9,12,14,18,21,24,27,30,33,36,39,42,45,46
         while not os.path.exists(user_input_directory):
@@ -242,7 +241,7 @@ for attempt in range(10):  # user has ten times to get a correct num of pcs desi
     break
 
 attempts_left = 10
-os.chmod('mGenerate_PyMOL_Session.py', stat.S_IRWXU)
+os.chmod('mGenerate_PyMOL_Session.sh', stat.S_IRWXU)
 print("______________________________________________________")
 print("Importing structures to PyMol")
 print("After reviewing the given plots, which of the files would you like to view in pyMol?")
