@@ -207,6 +207,7 @@ def xyz_contents(xyz_files, user_directory):
     comp_distances = False
     comp_angles = False
     comp_dihedrals = False
+    atoms_list = None
 
     while True:
         try:
@@ -231,11 +232,19 @@ def xyz_contents(xyz_files, user_directory):
 
             userAtomsChoice = input("Atoms: ")
 
-            if userAtomsChoice == "all":
+            #[s for s in mylist if s.isdigit()]
+            # digits_Choices = [s for s in split_Choices if s.isdigit()]
+
+            split_choices_atom_num = userAtomsChoice.replace(',', '')
+            split_choices_atom_num = str(split_choices_atom_num)
+
+            if userAtomsChoice.lower() == "all":  # option 1: all atoms will be used
+                print("You chose to include all atoms")
                 atomsChoice = list(range(1, n_atoms_distangdih + 1))
 
-            else:
+            elif split_choices_atom_num.isdigit(): # option 2: atoms selected by atom number will be used
                 #  remove duplicates using set()
+                print("You chose to include atoms via atom number")
                 split_Choices = userAtomsChoice.split(",")
 
                 # removing any possible empty strings
@@ -246,6 +255,99 @@ def xyz_contents(xyz_files, user_directory):
                 atomsChoice.sort()
                 #  list(map(int, test_list) will make each number in list an int
 
+
+            else: # option 3: atoms types only will be used
+                print("You chose to include atoms via element")
+                userAtomsChoice = userAtomsChoice.upper() # ensure that inputs are uppercase
+                atom_number = 1
+                atomsChoice = []
+
+                for line in coordinates_structure:
+                    print(line)
+                    split_line = line.split()
+                    userAtoms_splitChoices = userAtomsChoice.split(",")
+
+                    if split_line[0] in userAtoms_splitChoices:
+                        print("True")
+                        print(split_line[0])
+                        atomsChoice.append(atom_number)
+                        print(atomsChoice)
+                        atom_number = atom_number + 1
+
+                    else:
+                        atom_number = atom_number + 1
+
+                    #     if split_line[0] == "C":
+                    #         # print("C atom found")
+                    #         carbon_instance = elements.Carbon(atomnum=atom_number)
+                    #         carbon_instance.cartesian = [split_line[1], split_line[2], split_line[3]]
+                    #         carbon_list.append(carbon_instance)
+                    #         listofatoms.append(carbon_instance)
+                    #         atoms_list.append(atom_number)
+                    #         atom_number = atom_number + 1
+                    #
+                    #     elif split_line[0] == "H":
+                    #         # print("H atom found")
+                    #         hydrogen_instance = elements.Hydrogen(atomnum=atom_number)
+                    #         hydrogen_instance.cartesian = [split_line[1], split_line[2], split_line[3]]
+                    #         hydrogen_list.append(hydrogen_instance)
+                    #         listofatoms.append(hydrogen_instance)
+                    #         atoms_list.append(atom_number)
+                    #         atom_number = atom_number + 1
+                    #
+                    #     elif split_line[0] == "O":
+                    #         # print("O atom found")
+                    #         oxygen_instance = elements.Oxygen(atomnum=atom_number)
+                    #         oxygen_instance.cartesian = [split_line[1], split_line[2], split_line[3]]
+                    #         oxygen_list.append(oxygen_instance)
+                    #         listofatoms.append(oxygen_instance)
+                    #         atoms_list.append(atom_number)
+                    #         atom_number = atom_number + 1
+                    #
+                    #     elif split_line[0] == "N":
+                    #         # print("N atom found")
+                    #         nitrogen_instance = elements.Nitrogen(atomnum=atom_number)
+                    #         nitrogen_instance.cartesian = [split_line[1], split_line[2], split_line[3]]
+                    #         nitrogen_list.append(nitrogen_instance)
+                    #         listofatoms.append(nitrogen_instance)
+                    #         atoms_list.append(atom_number)
+                    #         atom_number = atom_number + 1
+                    #
+                    #     elif split_line[0] == "F":
+                    #         # print("N atom found")
+                    #         fluorine_instance = elements.Fluorine(atomnum=atom_number)
+                    #         fluorine_instance.cartesian = [split_line[1], split_line[2], split_line[3]]
+                    #         fluorine_list.append(fluorine_instance)
+                    #         listofatoms.append(fluorine_instance)
+                    #         atoms_list.append(atom_number)
+                    #         atom_number = atom_number + 1
+                    #
+                    # print(atoms_list)
+
+
+            '''
+                  if userAtomsChioce is a list of elements (C,H,N) (option 2: using elements only)
+                      do same reading as below for one molecule;
+
+                      eg.
+                      atom_number = 1
+                      If split_line[0] is in userAtomsChoice list of elements
+                          great, its one of the atoms we want
+
+                          now do the same
+                              if split_line[0] == "C":
+                              # print("C atom found")
+                              carbon_instance = elements.Carbon(atomnum=atom_number)
+                              carbon_instance.cartesian = [split_line[1], split_line[2], split_line[3]]
+                              carbon_list.append(carbon_instance)
+                              listofatoms.append(carbon_instance)
+                              atom_number = atom_number + 1
+
+                  if it doesnt trigger the above if statement
+                      atom_number = atom_number + 1
+
+
+                  '''
             atoms_list = atomsChoice
             # print(atoms_list)
             atom_number = 1
@@ -254,7 +356,7 @@ def xyz_contents(xyz_files, user_directory):
                 if atom_number not in atoms_list:
                     # print("True")
                     # print(atom_number)
-                    atom_number = atom_number+1
+                    atom_number = atom_number + 1
                     continue
                 else:
                     split_line = line.split()
@@ -298,7 +400,7 @@ def xyz_contents(xyz_files, user_directory):
                         listofatoms.append(fluorine_instance)
                         atom_number = atom_number + 1
 
-
+            print()
             print("Would you like to compute distances? Y/N")
             user_comp_distances = input("Distances (Y/N): ").upper()
             if user_comp_distances == "Y":
@@ -313,6 +415,10 @@ def xyz_contents(xyz_files, user_directory):
                         if atom_2 > atom_1:
                             distances_indexes_list.append([atom_1, atom_2])
 
+                if not distances_indexes_list:
+                    # this means that your criteria for atoms/elements creates no proper dihedrals
+                    raise InvalidUserEntranceError("Error: Your criteria for atoms/elements creates no distances")
+
             elif user_comp_distances == "N":
                 print("Distances will NOT be computed")
                 comp_distances = False
@@ -339,6 +445,10 @@ def xyz_contents(xyz_files, user_directory):
                                 if atom_3 not in [atom_1, atom_2] and atom_3 > atom_1:
                                     angles_indexes_list.append([atom_1,atom_2,atom_3])
 
+                if not angles_indexes_list:
+                    # this means that your criteria for atoms/elements creates no proper dihedrals
+                    raise InvalidUserEntranceError("Error: Your criteria for atoms/elements creates no angles")
+
             elif user_comp_angles == "N":
                 print("Angles will NOT be computed")
                 comp_angles = False
@@ -413,6 +523,13 @@ def xyz_contents(xyz_files, user_directory):
                                             # if not test_equality:
                                             #     dihedral_indexes_list.append([atom_1, atom_2, atom_3, atom_4])
                                             """
+                if not proper_dihedrals_atoms:
+                    print(proper_dihedrals_atoms)
+                    # this means that your criteria for atoms/elements creates no proper dihedrals
+                    raise InvalidUserEntranceError(
+                        "Error: Your criteria for atoms/elements creates no proper dihedrals")
+
+
 
             elif user_comp_dihedrals == "N":
                 print("Dihedrals will NOT be computed")
